@@ -71,7 +71,9 @@ def train(model: torch.nn.Module,
         if isinstance(inputs, torch.Tensor):
             batch_size = inputs.shape[0]
         elif isinstance(inputs, torch.nn.utils.rnn.PackedSequence):
-            batch_size = inputs.data.shape[0]  # considering batch_first
+            # The minibatch size can be obtained as the number of samples for
+            # the first time sample
+            batch_size = inputs.batch_sizes[0]
         N += batch_size
 
         # For the metrics, we assumed to be averaged over the minibatch
@@ -87,8 +89,9 @@ def train(model: torch.nn.Module,
             pass
 
         if grad_clip is not None:
-            torch.nn.utils.clip_grad_value_(model.parameters(),
-                                            clip_value=grad_clip)
+            gradnorm = torch.nn.utils.clip_grad_norm_(model.parameters(),
+                                                      max_norm=grad_clip)
+            tensorboard_writer.add_scalar(f'grad/norm', gradnorm, num_epoch + (i+1)/tot_epoch)
 
         optimizer.step()
 
